# YAML Fu

YAML Fu is a YAML templating tool

## About

This package provides a command line utility and a Python library that generate YAML content fom processing yamlfu documents.


## Install

```bash
pip3 install --user yamlfu
```

## How to use (command ine tool)
```bash
yamlfu input.yaml
```
